Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3136)

Unified Diff: chrome/browser/ui/cocoa/browser_window_controller.mm

Issue 10037008: Fix window shadows. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase only Created 8 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/cocoa/browser_window_controller.mm
diff --git a/chrome/browser/ui/cocoa/browser_window_controller.mm b/chrome/browser/ui/cocoa/browser_window_controller.mm
index 89a1b9eec4fdcd5406a7d69ebc598a9fb85159b4..ec6fd54e6135e2637e58c7f72f51cdf95bfa0d0e 100644
--- a/chrome/browser/ui/cocoa/browser_window_controller.mm
+++ b/chrome/browser/ui/cocoa/browser_window_controller.mm
@@ -233,9 +233,12 @@ enum {
// be big enough to hold all locks that'll ever be needed.
barVisibilityLocks_.reset([[NSMutableSet setWithCapacity:10] retain]);
- // Sets the window to not have rounded corners, which prevents
- // the resize control from being inset slightly and looking ugly.
- if ([window respondsToSelector:@selector(setBottomCornerRounded:)])
+ // Set the window to not have rounded corners, which prevents the resize
+ // control from being inset slightly and looking ugly. Only bother to do
+ // this on Snow Leopard and earlier; on Lion and later all windows have
+ // rounded bottom corners, and this won't work anyway.
+ if (base::mac::IsOSSnowLeopardOrEarlier() &&
+ [window respondsToSelector:@selector(setBottomCornerRounded:)])
[window setBottomCornerRounded:NO];
// Lion will attempt to automagically save and restore the UI. This
« no previous file with comments | « chrome/browser/ui/cocoa/browser_frame_view.mm ('k') | content/browser/renderer_host/accelerated_plugin_view_mac.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698